@@ -93,7 +93,7 @@ def translate_response(xml, language):
     return tostring(document, encoding='utf-8')
 
 
-TRANSLATE_API_URL = 'http://translate.google.co.jp/'
+TRANSLATE_API_URL = 'https://translate.google.co.jp/'
 
 
 def translate(text, language):
